@@ -8,7 +8,8 @@ utils::globalVariables(c("ni", "fi", "sumatorio", "variable2",
                          "varianza.regresion","valores.teoricos","errores",
                          "obs","sc.observados","sc.teoricos","errores2","suma.cuadrados.total",
                          "suma.cuadrados.errores","suma.cuadrados.regresion","varianza.residual",
-                         "varianza.residuos","influencia","puntos.influyentes","error.norm",
+                         "varianza.residuos", "leverage", "puntos.palanca","error.norm",
                          "X","momento", "atipico", "lm", "mediamovil", "paso1_ive",
                          "periodo", "pivot_wider", "variable_serie",
-                         "A1","A2","c1","c2","c3","error_asimetria","var_coef","prediccion","."))
+                         "A1","A2","c1","c2","c3","error_asimetria","var_coef","prediccion",".",
+                         "variable1","variable2"))
