@@ -8,12 +8,16 @@
 #' \if{latex}{\figure{qrtablabidimensional.png}{options: width=3cm}}
 #'
 #' @usage tabla.bidimensional(x,
-#'              distribucion = c("cruzada","condicionada"),
-#'              frecuencias = c("absolutas","relativas"),
-#'              exportar = FALSE)
+#' var_filas = NULL,
+#' var_columnas = NULL,
+#' distribucion = c("cruzada","condicionada"),
+#' frecuencias = c("absolutas","relativas"),
+#' exportar = FALSE)
 #'
 #' @param x Conjunto de datos. Tiene que ser un dataframe (al menos dos variables, es decir, dos columnas).
-#' @param distribucion Es un caracter. Por defecto se obtien la tabla cruzada (\code{distribucion = "cruzada"}). Para obtener las distribuciones condicionadas cambiar a \code{distribucion = "condicionada"}.
+#' @param var_filas Variable fila.Por defecto su valor es NUll y el usuario debe escribir el nombre o posición de la variable cuyos valores quiere representar por filas.
+#' @param var_columnas Variable columna. Por defecto su valor es NUll y el usuario debe escribir el nombre o posición de la variable cuyos valores quiere representar por columnas
+#' @param distribucion Es un carácter. Por defecto se obtien la tabla cruzada (\code{distribucion = "cruzada"}). Para obtener las distribuciones condicionadas cambiar a \code{distribucion = "condicionada"}.
 #' @param frecuencias Es un carácter. Por defecto se obtienen las frecuencias absolutas ordinarias (\code{frecuencias = "absolutas"}). Para obtener las frecuencias relativas ordinarias cambiar a \code{frecuencias = "relativas"}.
 #' @param exportar Para exportar los resultados a una hoja de cálculo Excel (\code{exportar = TRUE}).
 #'
@@ -26,9 +30,6 @@
 #' \strong{Rosario Martínez Verdú}.
 #' \emph{Economía Aplicada.}
 #'
-#' \strong{Cristina Pardo-García}.
-#' \emph{Métodos Cuantitativos para la Medición de la Cultura (MC2). Economía Aplicada.}
-#'
 #' Facultad de Economía. Universidad de Valencia (España)
 #'
 #' @references
@@ -43,6 +44,8 @@
 #'
 #' @export
 tabla.bidimensional <- function(x,
+                                var_filas = NULL,
+                                var_columnas = NULL,
                                 distribucion = c("cruzada","condicionada"),
                                 frecuencias = c("absolutas","relativas"),
                                 exportar = FALSE){
@@ -53,32 +56,60 @@ tabla.bidimensional <- function(x,
   frecuencias <- tolower(frecuencias)
   frecuencias <- match.arg(frecuencias)
 
+  x <- data.frame(x)
+  varnames <- names(x)
 
-  x <- as.data.frame(x) %>%
-    na.omit
-
-  varnames <- colnames(x)
-  numvariables <- length(x)
-
-  variable1 <- readline(prompt = "Intoduce el nombre de la variable 1 (filas): ")
-  variable2 <- readline(prompt = "Intoduce el nombre de la variable 2 (columnas): ")
-  variable <- c(variable1,variable2) #nombres de las variables
-
-  if(variable1 %in% varnames){
-    variable1 = which(varnames == variable1)
-  } else{
-    stop("Comprueba el nombre de la variable")
-  }
-  if(variable2 %in% varnames){
-    variable2 = which(varnames == variable2)
-  } else{
-    stop("Comprueba el nombre de la variable")
+  if(length(x)<2){
+    stop("El conjunto de datos seleccionada solo tiene una variable.")
   }
 
-  x <- x %>%
-    select(all_of(c(variable1,variable2)))
+  if(is.null(var_filas) | is.null(var_columnas)){
+    stop("Debes seleccionar la variable fila y columna")
+  }
 
-  names(x) <- c("filas","columnas")
+  if(is.numeric(var_filas)){
+    if(var_filas<=length(x)){
+      var_filas <- var_filas}
+    else{
+      stop("Selecci\u00f3n err\u00f3nea de variable")
+    }
+  }
+
+  if(is.character(var_filas)){
+    if(var_filas %in% varnames){
+      var_filas = match(var_filas,varnames)
+    } else {
+      stop("El nombre de la variable por filas no es v\u00e1lido")
+    }
+  }
+
+
+  if(is.numeric(var_columnas)){
+    if(var_columnas<=length(x)){
+      var_columnas <- var_columnas}
+    else{
+      stop("Selecci\u00f3n err\u00f3nea de variable")
+    }
+  }
+
+  if(is.character(var_columnas)){
+    if(var_columnas %in% varnames){
+      var_columnas = match(var_columnas,varnames)
+    } else {
+      stop("El nombre de la variable por columna no es v\u00e1lido")
+    }
+  }
+
+  if(var_filas == var_columnas){
+    stop("La variable por fila y columna es la misma variable")
+  }
+
+  variable <- c(var_filas,var_columnas)
+
+
+  x <- x[,variable] %>% as.data.frame()
+  names(x) <- varnames[variable]
+  varnames <- names(x)
 
   clase <- sapply(x, class)
 
@@ -95,8 +126,8 @@ tabla.bidimensional <- function(x,
       tabla <- addmargins(tabla)
 
     } else{
-      print("Si quieres obtener la distribuci\u00f3nes de variable1/variable2 (por filas) introduce el valor 1, en caso contrario variable2/variable1 (por columnas) introduce el valor 2")
-      tipo <- readline(prompt = "Distribuci\u00f3nes condicionadas por filas (1) o por columnas (2): ")
+      print("Si quieres obtener la distribuciones de variable1/variable2 (condici\u00f3n por columnas) introduce el valor 1, en caso contrario variable2/variable1 (condici\u00f3n por filas) introduce el valor 2")
+      tipo <- readline(prompt = "Distribuci\u00f3nes condicionadas por columnas (1) o por filas (2): ")
       tipo = as.numeric(tipo)
 
       tabla2 <- x %>%
